#include "StdAfx.h"
#include ".\Settings.h"

CSettings::CSettings(void)
{
	TCHAR buf[MAX_PATH];
	::GetModuleFileName(NULL, buf, _countof(buf));
	m_ExeFileName = buf;
	::PathRenameExtension(buf, _T(".ini"));
	m_IniFileName = buf;
	*::PathFindFileName(buf) = _T('\0');
	m_ExeDirectory = buf;
}

CSettings::~CSettings(void)
{
}

int CSettings::Load(void)
{
	GetPrivateProfileString(_T("Path"), _T("TsSplitter"), _T("TsSplitter.exe"), m_TsSplitter);
	GetPrivateProfileString(_T("Path"), _T("make_gl"), _T("make_gl.exe"), m_make_gl);
	GetPrivateProfileString(_T("Path"), _T("ts2aac"), _T("ts2aac.exe"), m_ts2aac);
	GetPrivateProfileString(_T("Path"), _T("aactool"), _T("aactool.exe"), m_aactool);
	GetPrivateProfileString(_T("Path"), _T("FAW"), _T("FAW.exe"), m_FAW);
	GetPrivateProfileString(_T("Path"), _T("CAP2ASS"), _T("Caption2Ass_mod1.exe"), m_CAP2ASS);

	GetPrivateProfileString(_T("Settings"), _T("LastInputPath"), _T(""), m_LastInputPath);
	GetPrivateProfileString(_T("Settings"), _T("DefaultOutputPath"), _T(""), m_DefaultOutputPath);
	m_SelectNum = GetPrivateProfileInt(_T("Settings"), _T("SelectNum"), 0);

	m_SettingList.RemoveAll();
	int count = GetPrivateProfileInt(_T("Settings"), _T("SettingCount"), 0);
	if (count == 0) {
		CSettingItem defaultItem;
		defaultItem.m_SettingName = _T("tsconv");
		defaultItem.m_BatchFile = _T("tsconv.bat");
		defaultItem.m_TsSplitter_opt = _T("-1SEG -SEP");
		defaultItem.m_CAP2ASS_opt = _T("-format srt");
		m_SettingList.Add(defaultItem);
	} else {
		for (int i = 0; i < count; i++) {
			CSettingItem item;
			CString strSection;
			strSection.Format(_T("Setting%d"), i);
			
			GetPrivateProfileString(strSection, _T("Name"), _T("tsconv"), item.m_SettingName);
			GetPrivateProfileString(strSection, _T("Batch"), _T("tsconv.bat"), item.m_BatchFile);
			
			item.m_Use_TsSplitter = GetPrivateProfileInt(strSection, _T("Use_TsSplitter"), TRUE);
			item.m_Use_make_gl = GetPrivateProfileInt(strSection, _T("Use_make_gl"), TRUE);
			item.m_Use_ts2aac = GetPrivateProfileInt(strSection, _T("Use_ts2aac"), TRUE);
			item.m_Use_aactool = GetPrivateProfileInt(strSection, _T("Use_aactool"), FALSE);
			item.m_Use_FAW = GetPrivateProfileInt(strSection, _T("Use_FAW"), TRUE);
			item.m_Use_CAP2ASS = GetPrivateProfileInt(strSection, _T("Use_CAP2ASS"), TRUE);
			
			GetPrivateProfileString(strSection, _T("TsSplitter_opt"), _T("-1SEG -SEP"), item.m_TsSplitter_opt);
			GetPrivateProfileString(strSection, _T("ts2aac_opt"), _T(""), item.m_ts2aac_opt);
			GetPrivateProfileString(strSection, _T("aactool_opt"), _T(""), item.m_aactool_opt);
			GetPrivateProfileString(strSection, _T("CAP2ASS_opt"), _T("-format srt"), item.m_CAP2ASS_opt);
			
			GetPrivateProfileString(strSection, _T("options"), _T(""), item.m_options);
			
			m_SettingList.Add(item);
		}
	}

	return 0;
}

int CSettings::Save(void)
{
	WritePrivateProfileString(_T("Path"), _T("TsSplitter"), m_TsSplitter);
	WritePrivateProfileString(_T("Path"), _T("make_gl"), m_make_gl);
	WritePrivateProfileString(_T("Path"), _T("ts2aac"), m_ts2aac);
	WritePrivateProfileString(_T("Path"), _T("aactool"), m_aactool);
	WritePrivateProfileString(_T("Path"), _T("FAW"), m_FAW);
	WritePrivateProfileString(_T("Path"), _T("CAP2ASS"), m_CAP2ASS);

	WritePrivateProfileString(_T("Settings"), _T("LastInputPath"), m_LastInputPath);
	WritePrivateProfileString(_T("Settings"), _T("DefaultOutputPath"), m_DefaultOutputPath);
	WritePrivateProfileInt(_T("Settings"), _T("SelectNum"), m_SelectNum);

	int count = m_SettingList.GetSize();
	WritePrivateProfileInt(_T("Settings"), _T("SettingCount"), count);
	for (int i = 0; i < count; i++) {
		CSettingItem& item = m_SettingList[i];
		CString strSection;
		strSection.Format(_T("Setting%d"), i);
		
		WritePrivateProfileString(strSection, _T("Name"), item.m_SettingName);
		WritePrivateProfileString(strSection, _T("Batch"), item.m_BatchFile);
		
		WritePrivateProfileInt(strSection, _T("Use_TsSplitter"), item.m_Use_TsSplitter);
		WritePrivateProfileInt(strSection, _T("Use_make_gl"), item.m_Use_make_gl);
		WritePrivateProfileInt(strSection, _T("Use_ts2aac"), item.m_Use_ts2aac);
		WritePrivateProfileInt(strSection, _T("Use_aactool"), item.m_Use_aactool);
		WritePrivateProfileInt(strSection, _T("Use_FAW"), item.m_Use_FAW);
		WritePrivateProfileInt(strSection, _T("Use_CAP2ASS"), item.m_Use_CAP2ASS);
		
		WritePrivateProfileString(strSection, _T("TsSplitter_opt"), item.m_TsSplitter_opt);
		WritePrivateProfileString(strSection, _T("ts2aac_opt"), item.m_ts2aac_opt);
		WritePrivateProfileString(strSection, _T("aactool_opt"), item.m_aactool_opt);
		WritePrivateProfileString(strSection, _T("CAP2ASS_opt"), item.m_CAP2ASS_opt);
		
		WritePrivateProfileString(strSection, _T("options"), item.m_options);
	}
	return 0;
}
